@@ -78,7 +78,8 @@ gboolean colrow_is_default (ColRowInfo const *cri);
 gboolean colrow_is_empty   (ColRowInfo const *cri);
 gboolean colrow_equal	   (ColRowInfo const *a, ColRowInfo const *b);
 void     colrow_copy	   (ColRowInfo *dst, ColRowInfo const *src);
-#define  colrow_free	   g_free
+ColRowInfo *colrow_new (void);
+void colrow_free (ColRowInfo *cri);
 
 typedef struct {
 	int	pos;
@@ -140,10 +141,6 @@ void		 colrow_set_visibility_list	(Sheet *sheet, gboolean is_cols,
 
 /* Misc */
 #define		 colrow_max(is_cols,sheet)	((is_cols) ? gnm_sheet_get_max_cols (sheet) : gnm_sheet_get_max_rows (sheet))
-void             colrow_reset_defaults		(Sheet *sheet, gboolean is_cols, int maxima);
-int              colrow_find_adjacent_visible   (Sheet *sheet, gboolean is_cols,
-						 int index, gboolean forward);
-
 void             rows_height_update		(Sheet *sheet, GnmRange const *range,
 						 gboolean shrink);
 
