@@ -16,7 +16,7 @@ char const *gnm_sys_lib_dir    (void);
 char const *gnm_sys_data_dir   (void);
 char const *gnm_icon_dir       (void);
 char const *gnm_locale_dir     (void);
-char const *gnm_usr_dir	       (void);
+char const *gnm_usr_dir	       (gboolean versioned);
 
 #define PLUGIN_SUBDIR "plugins"
 
