@@ -24,9 +24,9 @@ struct _GnmSortData {
 };
 
 void gnm_sort_data_destroy   (GnmSortData *data);
-void gnm_sort_position 	     (GnmSortData *data, int *perm, GOCmdContext *cc);
-int *gnm_sort_contents 	     (GnmSortData *data, GOCmdContext *cc);
-int  gnm_sort_data_length    (GnmSortData const *data);
+GnmSortData *gnm_sort_data_copy   (GnmSortData *data);
+void gnm_sort_position	     (GnmSortData *data, int *perm, GOCmdContext *cc);
+int *gnm_sort_contents	     (GnmSortData *data, GOCmdContext *cc);
 int *gnm_sort_permute_invert (int const *perm, int length);
 
 G_END_DECLS
